==> huaweicloudsdkdrs-3.1.133-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/update_agency_policy_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAgencyPolicyRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'agency_name': 'str',
        'body': 'UpdateAgencyPolicyRequestBody'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'agency_name': 'agency_name',
        'body': 'body'
    }

    def __init__(self, x_language=None, agency_name=None, body=None):
        """UpdateAgencyPolicyRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。默认en-us。 取值范围： - en-us - zh-cn
        :type x_language: str
        :param agency_name: 委托名称。
        :type agency_name: str
        :param body: Body of the UpdateAgencyPolicyRequest
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateAgencyPolicyRequestBody`
        """
        
        

        self._x_language = None
        self._agency_name = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.agency_name = agency_name
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this UpdateAgencyPolicyRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :return: The x_language of this UpdateAgencyPolicyRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this UpdateAgencyPolicyRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :param x_language: The x_language of this UpdateAgencyPolicyRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def agency_name(self):
        """Gets the agency_name of this UpdateAgencyPolicyRequest.

        委托名称。

        :return: The agency_name of this UpdateAgencyPolicyRequest.
        :rtype: str
        """
        return self._agency_name

    @agency_name.setter
    def agency_name(self, agency_name):
        """Sets the agency_name of this UpdateAgencyPolicyRequest.

        委托名称。

        :param agency_name: The agency_name of this UpdateAgencyPolicyRequest.
        :type agency_name: str
        """
        self._agency_name = agency_name

    @property
    def body(self):
        """Gets the body of this UpdateAgencyPolicyRequest.

        :return: The body of this UpdateAgencyPolicyRequest.
        :rtype: :class:`huaweicloudsdkdrs.v5.UpdateAgencyPolicyRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateAgencyPolicyRequest.

        :param body: The body of this UpdateAgencyPolicyRequest.
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateAgencyPolicyRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAgencyPolicyRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.152-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/update_agency_policy_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAgencyPolicyRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'agency_name': 'str',
        'body': 'UpdateAgencyPolicyRequestBody'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'agency_name': 'agency_name',
        'body': 'body'
    }

    def __init__(self, x_language=None, agency_name=None, body=None):
        r"""UpdateAgencyPolicyRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。默认en-us。 取值范围： - en-us - zh-cn
        :type x_language: str
        :param agency_name: 委托名称。
        :type agency_name: str
        :param body: Body of the UpdateAgencyPolicyRequest
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateAgencyPolicyRequestBody`
        """
        
        

        self._x_language = None
        self._agency_name = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.agency_name = agency_name
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        r"""Gets the x_language of this UpdateAgencyPolicyRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :return: The x_language of this UpdateAgencyPolicyRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        r"""Sets the x_language of this UpdateAgencyPolicyRequest.

        请求语言类型。默认en-us。 取值范围： - en-us - zh-cn

        :param x_language: The x_language of this UpdateAgencyPolicyRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def agency_name(self):
        r"""Gets the agency_name of this UpdateAgencyPolicyRequest.

        委托名称。

        :return: The agency_name of this UpdateAgencyPolicyRequest.
        :rtype: str
        """
        return self._agency_name

    @agency_name.setter
    def agency_name(self, agency_name):
        r"""Sets the agency_name of this UpdateAgencyPolicyRequest.

        委托名称。

        :param agency_name: The agency_name of this UpdateAgencyPolicyRequest.
        :type agency_name: str
        """
        self._agency_name = agency_name

    @property
    def body(self):
        r"""Gets the body of this UpdateAgencyPolicyRequest.

        :return: The body of this UpdateAgencyPolicyRequest.
        :rtype: :class:`huaweicloudsdkdrs.v5.UpdateAgencyPolicyRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateAgencyPolicyRequest.

        :param body: The body of this UpdateAgencyPolicyRequest.
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateAgencyPolicyRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAgencyPolicyRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
